@@ -1,3 +1,3 @@
 from admin_controller import AdminController, add_admin_handler
 
-__all__ = ['add_admin_handler', 'AdminController']
\ No newline at end of file
+__all__ = ['AdminController', 'add_admin_handler']
